@@ -17,15 +17,24 @@ class BBBDLC:
         }
 
         try:
-            os.chdir(args.ncDir)
+            serverName = args.serverName
+            serverDir = args.serverDir
+            
+            while (serverDir != "/" and os.path.basename(serverDir) != serverName):
+                serverDir = os.path.dirname(serverDir)
+            
+            if serverDir == "/": raise NameError('Could not find nextcloud folder!')
+            serverDir += "/nextcloud"
 
-            occCommand = "/opt/plesk/php/7.3/bin/php " + args.ncDir + "/occ "
-            os.system(occCommand + "config:system:get datadirectory >> ncPath.txt")
+            os.chdir(serverDir)
 
-            ncPathFile = open(args.ncDir + "ncPath.txt", "r")
-            ncPath = ncPathFile.readline()
+            occCommand = "/opt/plesk/php/7.3/bin/php " + serverDir + "/occ "
+            os.system(occCommand + "config:system:get datadirectory > ncPath.txt")
+
+            ncPathFile = open(serverDir + "/ncPath.txt", "r")
+            ncPath = ncPathFile.readline().strip()
             ncPathFile.close()
-            os.system("rm " + args.ncDir + "ncPath.txt")
+            os.system("rm " + serverDir + "/ncPath.txt")
 
             if ncPath == "": raise NameError('Could not find nextcloud config!')
             
@@ -34,7 +43,7 @@ class BBBDLC:
             passthroughArgs = ""
 
             for arg in vars(args):
-                if arg == "recordId" or arg == "server" or arg == "secret" or arg == "ncDir": continue
+                if arg == "recordId" or arg == "server" or arg == "secret" or arg == "serverName" or arg == "serverDir": continue
                 if getattr(args, arg) == None or getattr(args, arg) == False: continue
 
                 arg = arg.replace("_", "-")
@@ -44,8 +53,6 @@ class BBBDLC:
             passthroughArgs += recordingUrl
             os.chdir(ncPath + "/admin/files")
             os.system("ianes-bbb-dl " + passthroughArgs)
-            os.system("mv " + args.recordId + "/slideshow.mp4 " + args.recordId + "v.mp4")
-            os.system("rm -r " + args.recordId)
             os.system(occCommand + "files:scan admin")
         except Exception as e:
             now = datetime.now()
@@ -78,7 +85,9 @@ def get_parser():
         description=('Big Blue Button Converter and Downloader')
     )
 
-    parser.add_argument('ncDir', type=str, help='Nextcloud install directory')
+    parser.add_argument('serverName', type=str, help='Server name')
+
+    parser.add_argument('serverDir', type=str, help='Server install directory')
 
     parser.add_argument('recordId', type=str, help='Recording ID of a lesson')
 
